@@ -36,7 +36,7 @@ class DataGetter():
         print(os.getcwd())
         self.log_file_name = open(self.log_file,self.file_mode)
         """
-        self.log_file_name = open('logs/dataLoadLogs.txt', 'a+')
+        self.log_file_name = open('pneuro/logs/dataLoadLogs.txt', 'a+')
         self.logger = appLogger.AppLogger()
 
     def read_data_from_csv(self, file_name):
