@@ -2,7 +2,8 @@ import pickle
 import os
 import shutil
 
-from appLogger import AppLogger
+#from appLogger import AppLogger
+from pneuro import appLogger
 
 
 class FileOperation:
@@ -17,8 +18,8 @@ class FileOperation:
                 """
 
     def __init__(self):
-        self.file_object = open('logs/fileOperationLogs.txt', 'a+')
-        self.logger_object = AppLogger()
+        self.file_object = open('pneuro/logs/fileOperationLogs.txt', 'a+')
+        self.logger_object = appLogger.AppLogger()
         self.model_directory = 'models/'
 
     def save_model(self, model, filename):
