@@ -22,7 +22,7 @@ class Preprocessor():
     """
 
     def __init__(self):
-        self.file_object = open('logs/dataPreprocessingLogs.txt', 'a+')
+        self.file_object = open('pneuro/logs/dataPreprocessingLogs.txt', 'a+')
         self.logger_object = applogger.AppLogger()
 
     def get_data_profile(self, data):
