@@ -30,7 +30,7 @@ class Prediction():
                         Revisions: None
 
                 """
-        self.file_object = open('logs/predictionLogs.txt', 'a+')
+        self.file_object = open('pneuro/logs/predictionLogs.txt', 'a+')
         self.logger = applogger.AppLogger()
         self.file_operation = file_methods.FileOperation()
         self.models_directory = 'models'
