@@ -19,8 +19,9 @@ class RegressionModelTuner():
     """
 
     def __init__(self):
-        self.file_object = open('RegressionLogs.txt', 'a+')
-        self.logger_object = appLogger.App_Logger()
+      #self.file_object = open('RegressionLogs.txt', 'a+')
+      self.file_object = open('pneuro/logs/RegressionLogs.txt', 'a+')
+      self.logger_object = appLogger.App_Logger()
 
     def get_tuned_knn_model(self, x_train, y_train):
         """
